package jalview.analysis.scoremodels;

import static org.testng.Assert.assertEquals;

import org.testng.annotations.Test;

public class ScoreMatrixTest
{
  @Test(groups = "Functional")
  public void testBuildSymbolIndex()
  {
    short[] index = ScoreMatrix.buildSymbolIndex("AX-. yxYp".toCharArray());

    assertEquals(index.length, 128); // ASCII character set size

    assertEquals(index['A'], 0);
    assertEquals(index['a'], 0); // lower-case mapping added
    assertEquals(index['X'], 1);
    assertEquals(index['-'], 2);
    assertEquals(index['.'], 3);
    assertEquals(index[' '], 4);
    assertEquals(index['y'], 5); // lower-case override
    assertEquals(index['x'], 6); // lower-case override
    assertEquals(index['Y'], 7);
    assertEquals(index['p'], 8);
    assertEquals(index['P'], -1); // lower-case doesn't map upper-case

    /*
     * check all unmapped symbols have index for unmapped
     */
    for (int c = 0; c < index.length; c++)
    {
      if (!"AaXx-. Yyp".contains(String.valueOf((char) c)))
      {
        assertEquals(index[c], -1);
      }
    }
  }

  /**
   * check that characters not in the basic ASCII set are simply ignored
   */
  @Test(groups = "Functional")
  public void testBuildSymbolIndex_nonAscii()
  {
    char[] weird = new char[] { 128, 245, 'P' };
    short[] index = ScoreMatrix.buildSymbolIndex(weird);
    assertEquals(index.length, 128);
    assertEquals(index['P'], 2);
    assertEquals(index['p'], 2);
    for (int c = 0; c < index.length; c++)
    {
      if (c != 'P' && c != 'p')
      {
        assertEquals(index[c], -1);
      }
    }
  }
}
